﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace INS16ISample
{
    public partial class Form1 : Form
    {
        private short DevId;
        private System.Windows.Forms.PictureBox[] StatDisp;
        private System.Windows.Forms.PictureBox[] DirCntl;
        private System.Windows.Forms.PictureBox[] EdgeDisp;

        public Form1()
        {
            InitializeComponent();

            StatDisp = new System.Windows.Forms.PictureBox[]
                {DispB0, DispB1, DispB2, DispB3, DispB4, DispB5, DispB6, DispB7,
                DispB8, DispB9, DispB10, DispB11, DispB12, DispB13, DispB14, DispB15};

            DirCntl = new System.Windows.Forms.PictureBox[]
                {Dir0, Dir1, Dir2, Dir3, Dir4, Dir5, Dir6, Dir7, 
                Dir8, Dir9, Dir10, Dir11, Dir12, Dir13, Dir14, Dir15};

            EdgeDisp = new System.Windows.Forms.PictureBox[]
                {Edge0, Edge1, Edge2, Edge3, Edge4, Edge5, Edge6, Edge7,
                Edge8, Edge9, Edge10, Edge11, Edge12, Edge13, Edge14, Edge15};

        }

        private void ControlEnable(Boolean en)
        {
            DevOpenBtn.Enabled = ! en;
            IDNUM.Enabled = ! en;
            DevCloseBtn.Enabled = en;
            Timer1.Enabled = en;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            int Bit;

            DevId = 0;
            ControlEnable(false);
            
            Timer1.Interval = 300;
            IDNUM.SelectedIndex = 0;
            for( Bit = 0 ; Bit < 16 ; Bit++ )
            {
                StatDisp[Bit].Image = ImageList1.Images["Off"];
                DirCntl[Bit].Image = ImageList1.Images["UpEdge"];
                DirCntl[Bit].Tag = false;
                EdgeDisp[Bit].Image = ImageList1.Images["Off"];
            }
        }

        private void DevOpenBtn_Click(object sender, EventArgs e)
        {
            short retErr;

            DevId = (short) IDNUM.SelectedIndex;
            retErr = TUSBINSI.Tusbins16i_Device_Open(DevId);
            if (retErr == 0)
            {
                ControlEnable(true);
                EdgeSet();
            }
            else
                MessageBox.Show(TUSBINSI.GetOpenErrMessage(retErr));
        }

        private void DevClose()
        {
            TUSBINSI.Tusbins16i_Device_Close(DevId);
            ControlEnable(false);
        }

        private void DevCloseBtn_Click(object sender, EventArgs e)
        {
            DevClose();
        }

        private void EdgeSet()
        {
            int Bit;
            int dat;
            short retErr;

            dat = 0;
            for( Bit = 0 ; Bit < 16 ; Bit++ )
                dat += (((Boolean) DirCntl[Bit].Tag) ? (1 << Bit) : 0 );

            retErr = TUSBINSI.Tusbins16i_EdgeSet(DevId, dat, (byte) IntervalTime.Value);
            if( retErr != 0)
            {
                MessageBox.Show(TUSBINSI.GetErrMessage(retErr));
                DevClose();
            }
        }

        private void Dir_MouseClick(object sender, MouseEventArgs e)
        {
            System.Windows.Forms.PictureBox image  = (System.Windows.Forms.PictureBox) sender;

            if((Boolean) image.Tag)
            {
                image.Tag = false;
                image.Image = ImageList1.Images["UpEdge"];
            }
            else
            {
                image.Tag = true;
                image.Image = ImageList1.Images["DownEdge"];
            }
            EdgeSet();
        }

        private void Timer1_Tick(object sender, EventArgs e)
        {
            int dat;
            int Bit;
            short retErr;

            retErr = TUSBINSI.Tusbins16i_Read(DevId, out dat);
            if (retErr != 0) //***DLL関数の実行
            {
                MessageBox.Show(TUSBINSI.GetErrMessage(retErr));
                DevClose();
                return;
            }
            else
            {
                for (Bit = 0; Bit < 16; Bit++)
                    StatDisp[Bit].Image = ((dat & (1 << Bit)) != 0) ? ImageList1.Images["On"] : ImageList1.Images["Off"];
            }

            retErr = TUSBINSI.Tusbins16i_EdgeRead(DevId, out dat);
            if (retErr != 0) //***DLL関数の実行
            {
                MessageBox.Show(TUSBINSI.GetErrMessage(retErr));
                DevClose();
                return;
            }
            else
            {
                for (Bit = 0; Bit < 16; Bit++)
                    EdgeDisp[Bit].Image = ((dat & (1 << Bit)) != 0) ? ImageList1.Images["On"] : ImageList1.Images["Off"];
            }
        }

        private void IntervalTime_ValueChanged(object sender, EventArgs e)
        {
            EdgeSet();
        }
    }
}
